@@ -5,18 +5,18 @@ if False:  # MYPY
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 17, 33),
-    __version__='0.17.33',
-    version_timestamp='2023-09-28 12:25:58',
+    version_info=(0, 17, 40),
+    __version__='0.17.40',
+    version_timestamp='2023-10-20 14:51:55',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
     entry_points=None,
     since=2014,
     extras_require={
-        ':platform_python_implementation=="CPython" and python_version<"3.12"': ['ruamel.yaml.clib>=0.2.7'],  # NOQA
+        ':platform_python_implementation=="CPython" and python_version<"3.13"': ['ruamel.yaml.clib>=0.2.7'],  # NOQA
         'jinja2': ['ruamel.yaml.jinja2>=0.2'],
-        'docs': ['ryd'],
+        'docs': ['ryd', 'mercurial>5.7'],
     },
     classifiers=[
         'Programming Language :: Python :: 3 :: Only',
@@ -25,6 +25,7 @@ _package_data = dict(
         'Programming Language :: Python :: 3.9',
         'Programming Language :: Python :: 3.10',
         'Programming Language :: Python :: 3.11',
+        'Programming Language :: Python :: 3.12',
         'Programming Language :: Python :: Implementation :: CPython',
         'Topic :: Software Development :: Libraries :: Python Modules',
         'Topic :: Text Processing :: Markup',
