@@ -48,6 +48,9 @@ class ScalarAnalysis:
         self.allow_double_quoted = allow_double_quoted
         self.allow_block = allow_block
 
+    def __repr__(self) -> str:
+        return f'scalar={self.scalar!r}, empty={self.empty}, multiline={self.multiline}, allow_flow_plain={self.allow_flow_plain}, allow_block_plain={self.allow_block_plain}, allow_single_quoted={self.allow_single_quoted}, allow_double_quoted={self.allow_double_quoted}, allow_block={self.allow_block}'  # NOQA
+
 
 class Indents:
     # replacement for the list based stack of None/int
@@ -69,7 +72,7 @@ class Indents:
             return False
 
     def seq_flow_align(
-        self, seq_indent: int, column: int, pre_comment: Optional[bool] = False
+        self, seq_indent: int, column: int, pre_comment: Optional[bool] = False,
     ) -> int:
         # extra spaces because of dash
         # nprint('seq_flow_align', self.values, pre_comment)
@@ -97,6 +100,12 @@ class Emitter:
     # fmt: on
 
     MAX_SIMPLE_KEY_LENGTH = 128
+    flow_seq_start = '['
+    flow_seq_end = ']'
+    flow_seq_separator = ','
+    flow_map_start = '{'
+    flow_map_end = '}'
+    flow_map_separator = ','
 
     def __init__(
         self,
@@ -277,7 +286,7 @@ class Emitter:
         return len(self.events) < count + 1
 
     def increase_indent(
-        self, flow: bool = False, sequence: Optional[bool] = None, indentless: bool = False
+        self, flow: bool = False, sequence: Optional[bool] = None, indentless: bool = False,
     ) -> None:
         self.indents.append(self.indent, sequence)
         if self.indent is None:  # top level
@@ -441,7 +450,7 @@ class Emitter:
                     self.write_post_comment(self.event)
                 if self.event.comment and self.event.comment[1]:
                     self.write_pre_comment(self.event)
-                    if self.event.flow_style:
+                    if self.event.flow_style and self.indents.values:
                         force_flow_indent = not self.indents.values[-1][1]
                 if (
                     self.flow_level
@@ -450,7 +459,7 @@ class Emitter:
                     or self.check_empty_mapping()
                 ):
                     self.expect_flow_mapping(
-                        single=self.event.nr_items == 1, force_flow_indent=force_flow_indent
+                        single=self.event.nr_items == 1, force_flow_indent=force_flow_indent,
                     )
                 else:
                     self.expect_block_mapping()
@@ -475,9 +484,9 @@ class Emitter:
         if force_flow_indent:
             self.increase_indent(flow=True, sequence=True)
         ind = self.indents.seq_flow_align(
-            self.best_sequence_indent, self.column, force_flow_indent
+            self.best_sequence_indent, self.column, force_flow_indent,
         )
-        self.write_indicator(' ' * ind + '[', True, whitespace=True)
+        self.write_indicator(' ' * ind + self.flow_seq_start, True, whitespace=True)
         if not force_flow_indent:
             self.increase_indent(flow=True, sequence=True)
         self.flow_context.append('[')
@@ -488,7 +497,7 @@ class Emitter:
             self.indent = self.indents.pop()
             popped = self.flow_context.pop()
             assert popped == '['
-            self.write_indicator(']', False)
+            self.write_indicator(self.flow_seq_end, False)
             if self.event.comment and self.event.comment[0]:
                 # eol comment on empty flow sequence
                 self.write_post_comment(self.event)
@@ -507,9 +516,12 @@ class Emitter:
             popped = self.flow_context.pop()
             assert popped == '['
             if self.canonical:
-                self.write_indicator(',', False)
+                # ToDo: so-39595807, maybe add a space to the flow_seq_separator
+                # and strip the last space, if space then indent, else do not
+                # not sure that [1,2,3] is a valid YAML seq
+                self.write_indicator(self.flow_seq_separator, False)
                 self.write_indent()
-            self.write_indicator(']', False)
+            self.write_indicator(self.flow_seq_end, False)
             if self.event.comment and self.event.comment[0]:
                 # eol comment on flow sequence
                 self.write_post_comment(self.event)
@@ -517,7 +529,7 @@ class Emitter:
                 self.no_newline = False
             self.state = self.states.pop()
         else:
-            self.write_indicator(',', False)
+            self.write_indicator(self.flow_seq_separator, False)
             if self.canonical or self.column > self.best_width:
                 self.write_indent()
             self.states.append(self.expect_flow_sequence_item)
@@ -526,14 +538,14 @@ class Emitter:
     # Flow mapping handlers.
 
     def expect_flow_mapping(
-        self, single: Optional[bool] = False, force_flow_indent: Optional[bool] = False
+        self, single: Optional[bool] = False, force_flow_indent: Optional[bool] = False,
     ) -> None:
         if force_flow_indent:
             self.increase_indent(flow=True, sequence=False)
         ind = self.indents.seq_flow_align(
-            self.best_sequence_indent, self.column, force_flow_indent
+            self.best_sequence_indent, self.column, force_flow_indent,
         )
-        map_init = '{'
+        map_init = self.flow_map_start
         if (
             single
             and self.flow_level
@@ -554,7 +566,7 @@ class Emitter:
             self.indent = self.indents.pop()
             popped = self.flow_context.pop()
             assert popped == '{'  # empty flow mapping
-            self.write_indicator('}', False)
+            self.write_indicator(self.flow_map_end, False)
             if self.event.comment and self.event.comment[0]:
                 # eol comment on empty mapping
                 self.write_post_comment(self.event)
@@ -580,10 +592,10 @@ class Emitter:
             popped = self.flow_context.pop()
             assert popped in ['{', '']
             if self.canonical:
-                self.write_indicator(',', False)
+                self.write_indicator(self.flow_map_separator, False)
                 self.write_indent()
             if popped != '':
-                self.write_indicator('}', False)
+                self.write_indicator(self.flow_map_end, False)
             if self.event.comment and self.event.comment[0]:
                 # eol comment on flow mapping, never reached on empty mappings
                 self.write_post_comment(self.event)
@@ -591,7 +603,7 @@ class Emitter:
                 self.no_newline = False
             self.state = self.states.pop()
         else:
-            self.write_indicator(',', False)
+            self.write_indicator(self.flow_map_separator, False)
             if self.canonical or self.column > self.best_width:
                 self.write_indent()
             if not self.canonical and self.check_simple_key():
@@ -603,7 +615,8 @@ class Emitter:
                 self.expect_node(mapping=True)
 
     def expect_flow_mapping_simple_value(self) -> None:
-        self.write_indicator(self.prefixed_colon, False)
+        if getattr(self.event, 'style', '?') != '-':  # suppress for flow style sets
+            self.write_indicator(self.prefixed_colon, False)
         self.states.append(self.expect_flow_mapping_key)
         self.expect_node(mapping=True)
 
@@ -674,7 +687,7 @@ class Emitter:
             self.write_indent()
             if self.check_simple_key():
                 if not isinstance(
-                    self.event, (SequenceStartEvent, MappingStartEvent)
+                    self.event, (SequenceStartEvent, MappingStartEvent),
                 ):  # sequence keys
                     try:
                         if self.event.style == '?':
@@ -832,7 +845,7 @@ class Emitter:
             self.analysis = self.analyze_scalar(self.event.value)
         if self.event.style == '"' or self.canonical:
             return '"'
-        if (not self.event.style or self.event.style == '?') and (
+        if (not self.event.style or self.event.style == '?' or self.event.style == '-') and (
             self.event.implicit[0] or not self.event.implicit[2]
         ):
             if not (
@@ -843,6 +856,8 @@ class Emitter:
                 or (not self.flow_level and self.analysis.allow_block_plain)
             ):
                 return ""
+            if self.event.style == '-':
+                return ""
         self.analysis.allow_block = True
         if self.event.style and self.event.style in '|>':
             if (
@@ -1734,7 +1749,6 @@ class RoundTripEmitter(Emitter):
         if not ctag:
             raise EmitterError('tag must not be empty')
         tag = str(ctag)
-        # print('handling', repr(tag))
         if tag == '!' or tag == '!!':
             return tag
         handle = ctag.handle
