@@ -275,7 +275,7 @@ class Parser:
 
     def parse_document_content(self) -> Any:
         if self.scanner.check_token(
-            DirectiveToken, DocumentStartToken, DocumentEndToken, StreamEndToken
+            DirectiveToken, DocumentStartToken, DocumentEndToken, StreamEndToken,
         ):
             event = self.process_empty_scalar(self.scanner.peek_token().start_mark)
             self.state = self.states.pop()
@@ -291,7 +291,7 @@ class Parser:
             if token.name == 'YAML':
                 if yaml_version is not None:
                     raise ParserError(
-                        None, None, 'found duplicate YAML directive', token.start_mark
+                        None, None, 'found duplicate YAML directive', token.start_mark,
                     )
                 major, minor = token.value
                 if major != 1:
@@ -481,14 +481,14 @@ class Parser:
                 comment = pt.split_old_comment()
             # nprint('pt1', comment)
             event = SequenceStartEvent(
-                anchor, tag, implicit, start_mark, end_mark, flow_style=False, comment=comment
+                anchor, tag, implicit, start_mark, end_mark, flow_style=False, comment=comment,
             )
             self.state = self.parse_block_sequence_first_entry
         elif block and self.scanner.check_token(BlockMappingStartToken):
             end_mark = self.scanner.peek_token().start_mark
             comment = self.scanner.peek_token().comment
             event = MappingStartEvent(
-                anchor, tag, implicit, start_mark, end_mark, flow_style=False, comment=comment
+                anchor, tag, implicit, start_mark, end_mark, flow_style=False, comment=comment,
             )
             self.state = self.parse_block_mapping_first_key
         elif anchor is not None or tag is not None:
@@ -556,7 +556,7 @@ class Parser:
             token = self.scanner.get_token()
             self.move_token_comment(token)
             if not self.scanner.check_token(
-                BlockEntryToken, KeyToken, ValueToken, BlockEndToken
+                BlockEntryToken, KeyToken, ValueToken, BlockEndToken,
             ):
                 self.states.append(self.parse_indentless_sequence_entry)
                 return self.parse_block_node()
@@ -674,7 +674,7 @@ class Parser:
             if self.scanner.check_token(KeyToken):
                 token = self.scanner.peek_token()
                 event: Any = MappingStartEvent(
-                    None, None, True, token.start_mark, token.end_mark, flow_style=True
+                    None, None, True, token.start_mark, token.end_mark, flow_style=True,
                 )
                 self.state = self.parse_flow_sequence_entry_mapping_key
                 return event
@@ -742,7 +742,7 @@ class Parser:
             if self.scanner.check_token(KeyToken):
                 token = self.scanner.get_token()
                 if not self.scanner.check_token(
-                    ValueToken, FlowEntryToken, FlowMappingEndToken
+                    ValueToken, FlowEntryToken, FlowMappingEndToken,
                 ):
                     self.states.append(self.parse_flow_mapping_value)
                     return self.parse_flow_node()
@@ -750,7 +750,7 @@ class Parser:
                     self.state = self.parse_flow_mapping_value
                     return self.process_empty_scalar(token.end_mark)
             elif self.resolver.processing_version > (1, 1) and self.scanner.check_token(
-                ValueToken
+                ValueToken,
             ):
                 self.state = self.parse_flow_mapping_value
                 return self.process_empty_scalar(self.scanner.peek_token().end_mark)
@@ -785,7 +785,7 @@ class Parser:
         return ScalarEvent(None, None, (True, False), "", mark, mark, comment=comment)
 
     def move_token_comment(
-        self, token: Any, nt: Optional[Any] = None, empty: Optional[bool] = False
+        self, token: Any, nt: Optional[Any] = None, empty: Optional[bool] = False,
     ) -> Any:
         pass
 
@@ -799,7 +799,7 @@ class RoundTripParser(Parser):
         tag.select_transform(True)
 
     def move_token_comment(
-        self, token: Any, nt: Optional[Any] = None, empty: Optional[bool] = False
+        self, token: Any, nt: Optional[Any] = None, empty: Optional[bool] = False,
     ) -> Any:
         token.move_old_comment(self.scanner.peek_token() if nt is None else nt, empty=empty)
 
@@ -811,7 +811,7 @@ class RoundTripParserSC(RoundTripParser):
     # if self.loader.comment_handling is not None
 
     def move_token_comment(
-        self: Any, token: Any, nt: Any = None, empty: Optional[bool] = False
+        self: Any, token: Any, nt: Any = None, empty: Optional[bool] = False,
     ) -> None:
         token.move_new_comment(self.scanner.peek_token() if nt is None else nt, empty=empty)
 
