@@ -130,9 +130,9 @@ class BaseResolver:
     def add_implicit_resolver_base(cls, tag: Any, regexp: Any, first: Any) -> None:
         if 'yaml_implicit_resolvers' not in cls.__dict__:
             # deepcopy doesn't work here
-            cls.yaml_implicit_resolvers = dict(
-                (k, cls.yaml_implicit_resolvers[k][:]) for k in cls.yaml_implicit_resolvers
-            )
+            cls.yaml_implicit_resolvers = {
+                k: cls.yaml_implicit_resolvers[k][:] for k in cls.yaml_implicit_resolvers
+            }
         if first is None:
             first = [None]
         for ch in first:
@@ -142,9 +142,9 @@ class BaseResolver:
     def add_implicit_resolver(cls, tag: Any, regexp: Any, first: Any) -> None:
         if 'yaml_implicit_resolvers' not in cls.__dict__:
             # deepcopy doesn't work here
-            cls.yaml_implicit_resolvers = dict(
-                (k, cls.yaml_implicit_resolvers[k][:]) for k in cls.yaml_implicit_resolvers
-            )
+            cls.yaml_implicit_resolvers = {
+                k: cls.yaml_implicit_resolvers[k][:] for k in cls.yaml_implicit_resolvers
+            }
         if first is None:
             first = [None]
         for ch in first:
@@ -237,7 +237,7 @@ class BaseResolver:
         self.resolver_prefix_paths.pop()
 
     def check_resolver_prefix(
-        self, depth: int, path: Any, kind: Any, current_node: Any, current_index: Any
+        self, depth: int, path: Any, kind: Any, current_node: Any, current_index: Any,
     ) -> bool:
         node_check, index_check = path[depth - 1]
         if isinstance(node_check, str):
@@ -307,7 +307,7 @@ class VersionedResolver(BaseResolver):
     """
 
     def __init__(
-        self, version: Optional[VersionType] = None, loader: Any = None, loadumper: Any = None
+        self, version: Optional[VersionType] = None, loader: Any = None, loadumper: Any = None,
     ) -> None:
         if loader is None and loadumper is not None:
             loader = loadumper
@@ -316,7 +316,7 @@ class VersionedResolver(BaseResolver):
         self._version_implicit_resolver: Dict[Any, Any] = {}
 
     def add_version_implicit_resolver(
-        self, version: VersionType, tag: Any, regexp: Any, first: Any
+        self, version: VersionType, tag: Any, regexp: Any, first: Any,
     ) -> None:
         if first is None:
             first = [None]
