@@ -57,7 +57,7 @@ class SimpleKey:
     # See below simple keys treatment.
 
     def __init__(
-        self, token_number: Any, required: Any, index: int, line: int, column: int, mark: Any
+        self, token_number: Any, required: Any, index: int, line: int, column: int, mark: Any,
     ) -> None:
         self.token_number = token_number
         self.required = required
@@ -539,7 +539,10 @@ class Scanner:
             # Are we allowed to start a new entry?
             if not self.allow_simple_key:
                 raise ScannerError(
-                    None, None, 'sequence entries are not allowed here', self.reader.get_mark()
+                    None,
+                    None,
+                    'sequence entries are not allowed here',
+                    self.reader.get_mark(),
                 )
             # We may need to add BLOCK-SEQUENCE-START.
             if self.add_indent(self.reader.column):
@@ -567,7 +570,7 @@ class Scanner:
             # Are we allowed to start a key (not nessesary a simple)?
             if not self.allow_simple_key:
                 raise ScannerError(
-                    None, None, 'mapping keys are not allowed here', self.reader.get_mark()
+                    None, None, 'mapping keys are not allowed here', self.reader.get_mark(),
                 )
 
             # We may need to add BLOCK-MAPPING-START.
@@ -594,7 +597,7 @@ class Scanner:
             key = self.possible_simple_keys[self.flow_level]
             del self.possible_simple_keys[self.flow_level]
             self.tokens.insert(
-                key.token_number - self.tokens_taken, KeyToken(key.mark, key.mark)
+                key.token_number - self.tokens_taken, KeyToken(key.mark, key.mark),
             )
 
             # If this key starts a new block mapping, we need to add
@@ -822,8 +825,9 @@ class Scanner:
             srf()
         found = False
         _the_end = _THE_END
+        white_space = ' \t' if self.flow_level > 0 else ' '
         while not found:
-            while srp() == ' ':
+            while srp() in white_space:
                 srf()
             if srp() == '#':
                 while srp() not in _the_end:
@@ -1112,7 +1116,7 @@ class Scanner:
                 style not in '|>'
                 or (self.scanner_processing_version == (1, 1))
                 and getattr(
-                    self.loader, 'top_level_block_style_scalar_no_indent_error_1_1', False
+                    self.loader, 'top_level_block_style_scalar_no_indent_error_1_1', False,
                 )
             ):
                 min_indent = 1
@@ -1290,16 +1294,24 @@ class Scanner:
         srp = self.reader.peek
         srf = self.reader.forward
         chunks = []
+        first_indent = -1
         max_indent = 0
         end_mark = self.reader.get_mark()
         while srp() in ' \r\n\x85\u2028\u2029':
             if srp() != ' ':
+                if first_indent < 0:
+                    first_indent = self.reader.column
                 chunks.append(self.scan_line_break())
                 end_mark = self.reader.get_mark()
             else:
                 srf()
                 if self.reader.column > max_indent:
                     max_indent = self.reader.column
+        if first_indent > 0 and max_indent > first_indent:
+            start_mark = self.reader.get_mark()
+            raise ScannerError(
+                'more indented follow up line than first in a block scalar', start_mark,
+            )
         return chunks, max_indent, end_mark
 
     def scan_block_scalar_breaks(self, indent: int) -> Any:
@@ -1492,7 +1504,9 @@ class Scanner:
                 break
             while True:
                 ch = srp(length)
-                if ch == ':' and srp(length + 1) not in _THE_END_SPACE_TAB:
+                if False and ch == ':' and srp(length + 1) == ',':
+                    break
+                elif ch == ':' and srp(length + 1) not in _THE_END_SPACE_TAB:
                     pass
                 elif ch == '?' and self.scanner_processing_version != (1, 1):
                     pass
@@ -1837,14 +1851,14 @@ class RoundTripScanner(Scanner):
         # We also need to add the check for `allow_simple_keys == True` to
         # `unwind_indent` before issuing BLOCK-END.
         # Scanners for block, flow, and plain scalars need to be modified.
-
         srp = self.reader.peek
         srf = self.reader.forward
         if self.reader.index == 0 and srp() == '\uFEFF':
             srf()
         found = False
+        white_space = ' \t' if self.flow_level > 0 else ' '
         while not found:
-            while srp() == ' ':
+            while srp() in white_space:
                 srf()
             ch = srp()
             if ch == '#':
@@ -1917,6 +1931,37 @@ class RoundTripScanner(Scanner):
     def scan_block_scalar(self, style: Any, rt: Optional[bool] = True) -> Any:
         return Scanner.scan_block_scalar(self, style, rt=rt)
 
+    def scan_uri_escapes(self, name: Any, start_mark: Any) -> Any:
+        """
+        The roundtripscanner doesn't do URI escaping
+        """
+        # See the specification for details.
+        srp = self.reader.peek
+        srf = self.reader.forward
+        code_bytes: List[Any] = []
+        chunk = ''
+        mark = self.reader.get_mark()
+        while srp() == '%':
+            chunk += '%'
+            srf()
+            for k in range(2):
+                if srp(k) not in '0123456789ABCDEFabcdef':
+                    raise ScannerError(
+                        f'while scanning an {name!s}',
+                        start_mark,
+                        f'expected URI escape sequence of 2 hexdecimal numbers, '
+                        f'but found {srp(k)!r}',
+                        self.reader.get_mark(),
+                    )
+            code_bytes.append(int(self.reader.prefix(2), 16))
+            chunk += self.reader.prefix(2)
+            srf(2)
+        try:
+            _ = bytes(code_bytes).decode('utf-8')
+        except UnicodeDecodeError as exc:
+            raise ScannerError(f'while scanning an {name!s}', start_mark, str(exc), mark)
+        return chunk
+
 
 # commenthandling 2021, differentiatiation not needed
 
@@ -2071,7 +2116,7 @@ class ScannedComments:
             return
         idx = 1
         while tokens[-idx].start_mark.line > comment_line or isinstance(
-            tokens[-idx], ValueToken
+            tokens[-idx], ValueToken,
         ):
             idx += 1
         xprintf('idx1', idx)
@@ -2083,7 +2128,7 @@ class ScannedComments:
             return
         try:
             if isinstance(tokens[-idx], ScalarToken) and isinstance(
-                tokens[-(idx + 1)], KeyToken
+                tokens[-(idx + 1)], KeyToken,
             ):
                 try:
                     eol_idx = self.unused.pop(0)
@@ -2098,7 +2143,7 @@ class ScannedComments:
             pass
         try:
             if isinstance(tokens[-idx], ScalarToken) and isinstance(
-                tokens[-(idx + 1)], (ValueToken, BlockEntryToken)
+                tokens[-(idx + 1)], (ValueToken, BlockEntryToken),
             ):
                 try:
                     eol_idx = self.unused.pop(0)
@@ -2132,7 +2177,7 @@ class ScannedComments:
 
     def str_unprocessed(self) -> Any:
         return ''.join(
-            (f'  {ind:2} {x.info()}\n' for ind, x in self.comments.items() if x.used == ' ')
+            (f'  {ind:2} {x.info()}\n' for ind, x in self.comments.items() if x.used == ' '),
         )
 
 
@@ -2211,11 +2256,11 @@ class RoundTripScannerSC(Scanner):  # RoundTripScanner Split Comments
                 # we have a comment
                 if start_mark.column == 0:
                     self.comments.add_full_line_comment(  # type: ignore
-                        comment, comment_start_mark.column, comment_start_mark.line
+                        comment, comment_start_mark.column, comment_start_mark.line,
                     )
                 else:
                     self.comments.add_eol_comment(  # type: ignore
-                        comment, comment_start_mark.column, comment_start_mark.line
+                        comment, comment_start_mark.column, comment_start_mark.line,
                     )
                     comment = ""
                 # gather any blank lines or full line comments following the comment as well
